@@ -230,14 +230,13 @@
                      accession="MS:1000527", name="highest observed m/z",
                      value=max(mass(x[[i]])), unitCvRef="MS",
                      unitAccession="MS:1000040", unitName="m/z"), file=file)
-      .writeXmlTag("cvParam", intend=4, attrs=c(cvRef="MS",
-                     accession="MS:1000285", name="total ion current",
-                     value=totalIonCurrent(x[[i]])), file=file)
-
     if (MALDIquant::isMassSpectrum(x[[i]])) {
       .writeXmlTag("cvParam", intend=4, attrs=c(cvRef="MS",
                      accession="MS:1000128", name="profile spectrum"),
                    file=file)
+      .writeXmlTag("cvParam", intend=4, attrs=c(cvRef="MS",
+                     accession="MS:1000285", name="total ion current",
+                     value=totalIonCurrent(x[[i]])), file=file)
     } else {
       .writeXmlTag("cvParam", intend=4, attrs=c(cvRef="MS",
                      accession="MS:1000127", name="centroid spectrum"),
@@ -326,7 +325,7 @@
       .writeXmlTag("cvParam", intend=3, file=file,
                    attrs=c(cvRef="MS", accession="MS:1000515",
                            name="intensity array", unitCvRef="MS",
-                           unitAccession="MS:1000131"))
+                           unitAccession="MS:1000131", unitName="number of counts"))
 
       for (i in seq(along=accession)) {
         .writeXmlTag("cvParam", intend=3, file=file,
@@ -380,7 +379,7 @@
     for (i in seq(along=accession)) {
       .writeXmlTag("cvParam", intend=6, file=file,
                    attrs=c(cvRef="IMS", accession=accession[i], name=name[i],
-                           value=value[i]))
+                           value=format(value[i], scientific=FALSE)))
     }
     .writeCloseXmlTag("scan", intend=5, file=file)
   .writeCloseXmlTag("scanList", intend=4, file=file)
@@ -410,7 +409,7 @@
     for (i in seq(along=accession)) {
       .writeXmlTag("cvParam", intend=6, file=file,
                    attrs=c(cvRef="IMS", accession=accession[i], name=name[i],
-                           value=value[i]))
+                           value=format(value[i], scientific=FALSE)))
     }
     .writeXmlTag("binary", intend=6, file=file)
   .writeCloseXmlTag("binaryDataArray", intend=5, file=file)
